summaryrefslogtreecommitdiffstats
path: root/include/cppuhelper/component.hxx
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2015-10-20 11:02:14 +0200
committerNoel Grandin <noelgrandin@gmail.com>2015-10-21 06:36:39 +0000
commit08233bd25849cc7d5d092aa073362c7766cbcc19 (patch)
treeef27b8d8b00e531e31eea084f7cce81b6cb0bcb2 /include/cppuhelper/component.hxx
parentcom::sun::star->css in include/cppu (diff)
downloadcore-08233bd25849cc7d5d092aa073362c7766cbcc19.tar.gz
core-08233bd25849cc7d5d092aa073362c7766cbcc19.zip
com::sun::star->css in include/cppuhelper
Change-Id: I3d9dcd4cd756a3f0d9cedd894377a117c9dbeecc Reviewed-on: https://gerrit.libreoffice.org/19486 Reviewed-by: Noel Grandin <noelgrandin@gmail.com> Tested-by: Noel Grandin <noelgrandin@gmail.com>
Diffstat (limited to 'include/cppuhelper/component.hxx')
-rw-r--r--include/cppuhelper/component.hxx38
1 files changed, 19 insertions, 19 deletions
diff --git a/include/cppuhelper/component.hxx b/include/cppuhelper/component.hxx
index ea140e453e78..0b43c488af11 100644
--- a/include/cppuhelper/component.hxx
+++ b/include/cppuhelper/component.hxx
@@ -33,9 +33,9 @@ namespace osl { class Mutex; }
namespace cppu
{
/** Deprecated. Helper for implementing com::sun::star::lang::XComponent.
Upon disposing objects of this class, sub-classes receive a disposing() call. Objects of
- this class can be held weakly, i.e. by a com::sun::star::uno::WeakReference. Object of
+ this class can be held weakly, i.e. by a css::uno::WeakReference. Object of
this class can be aggregated, i.e. incoming queryInterface() calls are delegated.
@attention
@@ -44,8 +44,8 @@ namespace cppu
*/
class CPPUHELPER_DLLPUBLIC OComponentHelper
: public ::cppu::OWeakAggObject
- , public ::com::sun::star::lang::XTypeProvider
- , public ::com::sun::star::lang::XComponent
+ , public css::lang::XTypeProvider
+ , public css::lang::XComponent
{
public:
/** Constructor.
@@ -60,12 +60,12 @@ public:
virtual ~OComponentHelper();
// XAggregation
- virtual ::com::sun::star::uno::Any SAL_CALL queryInterface(
- ::com::sun::star::uno::Type const & rType )
- throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
- virtual ::com::sun::star::uno::Any SAL_CALL queryAggregation(
- ::com::sun::star::uno::Type const & rType )
- throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ virtual css::uno::Any SAL_CALL queryInterface(
+ css::uno::Type const & rType )
+ throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ virtual css::uno::Any SAL_CALL queryAggregation(
+ css::uno::Type const & rType )
+ throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual void SAL_CALL acquire()
throw () SAL_OVERRIDE;
virtual void SAL_CALL release()
@@ -74,23 +74,23 @@ public:
/** @attention
XTypeProvider::getImplementationId() has to be implemented separately!
*/
- virtual ::com::sun::star::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId()
- throw(::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE = 0;
+ virtual css::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId()
+ throw(css::uno::RuntimeException, std::exception) SAL_OVERRIDE = 0;
/** @attention
XTypeProvider::getTypes() has to be re-implemented!
*/
- virtual ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Type > SAL_CALL getTypes()
- throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ virtual css::uno::Sequence< css::uno::Type > SAL_CALL getTypes()
+ throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
// XComponent
virtual void SAL_CALL dispose()
- throw(::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ throw(css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual void SAL_CALL addEventListener(
- const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XEventListener >& aListener )
- throw(::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ const css::uno::Reference< css::lang::XEventListener >& aListener )
+ throw(css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual void SAL_CALL removeEventListener(
- const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XEventListener >& aListener )
- throw(::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+ const css::uno::Reference< css::lang::XEventListener >& aListener )
+ throw(css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
protected:
/** Called in dispose method after the listeners were notified.
@@ -33,9 +33,9 @@ namespace osl { class Mutex; }
namespace cppu
{
-/** Deprecated. Helper for implementing com::sun::star::lang::XComponent.
+/** Deprecated. Helper for implementing css::lang::XComponent.
Upon disposing objects of this class, sub-classes receive a disposing() call. Objects of